@@ -77,12 +77,12 @@ def seas_table(hist, fwd=None):
     summer = summary.iloc[[1, 2], :].mean()
     summer.name = "Q2+Q3"
     summary.index = ["Q1", "Q2", "Q3", "Q4"]
-    summary = summary.append(winter)
-    summary = summary.append(summer)
+    summary = pd.concat([summary, pd.DataFrame([winter])])
+    summary = pd.concat([summary, pd.DataFrame([summer])])
     cal = df.resample("Y").mean().iloc[0]
     cal.name = "Year"
-    summary = summary.append(cal)
-    summary = summary.round(2)
+    summary = pd.concat([summary, pd.DataFrame([cal])])
+    summary = round(summary, 2)
 
     df.index = df.index.strftime("%b")
     df = pd.concat([df, summary], sort=False).round(2)
@@ -100,15 +100,15 @@ def delta_summary_str(df, precision_format: str = None):
     df = df.dropna()
     val1 = df.iloc[-1]
     val2 = df.iloc[-2]
-    delta = (val1 - val2).round(2)
+    delta = round(val1 - val2, 2)
     symb = "+" if delta > 0.0 else ""
 
     if precision_format:
         val1, delta = precision_format.format(val1), precision_format.format(delta)
     else:
-        val1 = val1.round(2)
+        val1 = round(val1, 2)
 
-    s = "{}   △: {}{}".format(val1, symb, delta)
+    s = "{}   \u0394: {}{}".format(val1, symb, delta)
     return s
 
 
